==> micro_tacjs-1.0.0.tar.gz: micro_tacjs/src/MicroTacJSConfigOverrides.php <==
<?php

namespace Drupal\micro_tacjs;

use Drupal\micro_site\Entity\SiteInterface;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;

/**
 * Override TacJS configuration per micro site.
 *
 * @package Drupal\micro_site
 */
class MicroTacJSConfigOverrides implements ConfigFactoryOverrideInterface {

  /**
   * The active micro site or NULL.
   *
   * @var \Drupal\micro_site\Entity\SiteInterface|null
   */
  protected $activeSite = NULL;

  /**
   * {@inheritdoc}
   */
  public function loadOverrides($names) {
    $overrides = [];

    if (in_array('tacjs.settings', $names)) {
      $site = $this->getActiveSite();
      if ($site instanceof SiteInterface) {
        $data_tacjs = $site->getData('micro_tacjs');
        $data_services = $site->getData('micro_tacjs_services');
        $services = [];
        foreach ($data_services as $key => $value) {
          $settings = explode('_', $key);
          $services[$settings[0]][$settings[1]] = $value;
        }
        if ($data_tacjs && $data_services) {
          $overrides['tacjs.settings'] = ['dialog' => $data_tacjs] + $services;
        }
      }
    }

    return $overrides;
  }

  /**
   * Get active site.
   */
  protected function getActiveSite() {
    // I don't use here a dependency injection because of a
    // CircularReferenceException thrown when injecting the negotiator.
    if (is_null($this->activeSite)) {
      /** @var \Drupal\micro_site\SiteNegotiatorInterface $negotiator */
      $negotiator = \Drupal::service('micro_site.negotiator');
      /** @var \Drupal\micro_site\Entity\SiteInterface $site */
      $this->activeSite = $negotiator->getActiveSite();
    }
    return $this->activeSite;

  }

  /**
   * {@inheritdoc}
   */
  public function getCacheSuffix() {
    return 'MicroTacJSConfigurationOverrider';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($name) {
    $meta = new CacheableMetadata();
    return $meta;
  }

  /**
   * {@inheritdoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION) {
    return NULL;
  }

}

==> micro_tacjs-1.0.2.tar.gz: micro_tacjs/src/MicroTacJSConfigOverrides.php <==
<?php

namespace Drupal\micro_tacjs;

use Drupal\micro_site\Entity\SiteInterface;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;

/**
 * Override TacJS configuration per micro site.
 *
 * @package Drupal\micro_site
 */
class MicroTacJSConfigOverrides implements ConfigFactoryOverrideInterface {

  /**
   * The active micro site or NULL.
   *
   * @var \Drupal\micro_site\Entity\SiteInterface|null
   */
  protected $activeSite = NULL;

  /**
   * {@inheritdoc}
   */
  public function loadOverrides($names) {
    $overrides = [];

    if (in_array('tacjs.settings', $names)) {
      $site = $this->getActiveSite();
      if ($site instanceof SiteInterface) {
        $data_tacjs = $site->getData('micro_tacjs');
        $data_services = $site->getData('micro_tacjs_services');
        $services = [];
        foreach ($data_services as $key => $value) {
          $settings = explode('_', $key);
          $services[preg_replace('/service/', 'services', $settings[0])][$settings[1]] = $value;
        }
        if ($data_tacjs && $data_services) {
          $overrides['tacjs.settings'] = ['dialog' => $data_tacjs] + $services;
        }
      }
    }

    return $overrides;
  }

  /**
   * Get active site.
   */
  protected function getActiveSite() {
    // I don't use here a dependency injection because of a
    // CircularReferenceException thrown when injecting the negotiator.
    if (is_null($this->activeSite)) {
      /** @var \Drupal\micro_site\SiteNegotiatorInterface $negotiator */
      $negotiator = \Drupal::service('micro_site.negotiator');
      /** @var \Drupal\micro_site\Entity\SiteInterface $site */
      $this->activeSite = $negotiator->getActiveSite();
    }
    return $this->activeSite;

  }

  /**
   * {@inheritdoc}
   */
  public function getCacheSuffix() {
    return 'MicroTacJSConfigurationOverrider';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($name) {
    $meta = new CacheableMetadata();
    return $meta;
  }

  /**
   * {@inheritdoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION) {
    return NULL;
  }

}
